Overview
==================

Preparations
----------------

1. :doc:`Build the Correlation Structure for Your Task </tutorial/structure>`.
2. :doc:`Build the Input Data for Your Task </tutorial/dataset>`.
3. :doc:`Build the Model for Your Task </tutorial/model>`.
4. :doc:`Build the Evaluator for Your Task </tutorial/metric>`.


Training and Evaluation
------------------------------

1. :doc:`Build Your Training and Evaluation Code </tutorial/train>`.
2. :doc:`Auto-Hyperparameter Tuning </tutorial/auto_ml>`.


Others
-----------

- :doc:`Random Correlation Structure Generation </tutorial/random>`.
- :doc:`Structure Visualization </tutorial/vis_structure>`.
- :doc:`Feature Visualization </tutorial/vis_feature>`.

